==> frontengine-0.0.41.tar.gz: frontengine-0.0.41/README.md <==

[![Downloads](https://static.pepy.tech/badge/frontengine)](https://pepy.tech/project/frontengine)

[![Documentation Status](https://readthedocs.org/projects/frontengine/badge/?version=latest)](https://frontengine.readthedocs.io/en/latest/?badge=latest)

[FrontEngine Doc Click Here!](https://frontengine.readthedocs.io/en/latest/)

## Contents

> Project kanban https://github.com/orgs/Integration-Automation/projects/2/views/1

---
- [About](#about)
- [Features](#features)
- [Download](#download)

---

## About

---
> * Notice! BingGPT need cookies file now!
> * Save cookie to bing_cookies.json and put json in program current-working-dir
> - Open bing.com/chat
> - If you see a chat feature, you are good to continue...
> - Install the cookie editor extension for Chrome or Firefox
> - Go to bing.com
> - Open the extension
> - Click "Export" on the bottom right, then "Export as JSON" (This saves your cookies to clipboard)
> - Paste your cookies into a file bing_cookies.json.
> - NOTE: The cookies file name MUST follow the regex pattern bbing_cookies.json, so that they could be recognized by internal cookie processing mechanisms
* Smart automation assistant.
* Chat based automation.
* User-defined front ground.
* User-defined virtual assistant.
* Assistant can open website.
* Assistant can draw text on your screen.
* Assistant can play video on your screen.
* Assistant can play sound.
* Cowork with another automation components.  
* Extendable.
* Remote automation support.

![FrontEngine UI](image/FrontEngine.png)

* Language Menu (Choose ui language)
* UI Style (Choose ui style)
* Tab Menu
    * VIDEO (Setting and show video on front)
    * IMAGE (Setting and show image on front)
    * WEB (Setting and show web on front)
    * GIF AND WEBP (Setting and show gif or webp on front)
    * SOUND (Setting and play sound)
    * TEXT (Setting and show text on front)
    * SCENE (Add multi component on scene and show multi widget, can save setting as file)
    * CHAT (Chat with bing on front)
    * CONTROL CENTER (Control all another widget)
 
## Features

---

* GIFs need time to load please, wait.

* Video

![Video](gifs/video.gif)

* Website

![Website](gifs/website.gif)

* GIF & WEBP.

![GIF](gifs/play_gif.gif)
![WEBP](gifs/webp.gif)

- [Youtube](https://youtu.be/fewogcb3b8Y)

## Download

---
> Require Windows 10 or 11. \
> If you want to use this on a Unix-like system, you need to compile the source code.
- [Download](https://github.com/Intergration-Automation-Testing/FrontEngine/releases)

> PYPI package: pip install frontengine

==> frontengine-0.0.48.tar.gz: frontengine-0.0.48/README.md <==
[![Downloads](https://static.pepy.tech/badge/frontengine)](https://pepy.tech/project/frontengine)

[![Documentation Status](https://readthedocs.org/projects/frontengine/badge/?version=latest)](https://frontengine.readthedocs.io/en/latest/?badge=latest)

[FrontEngine Doc Click Here!](https://frontengine.readthedocs.io/en/latest/)

## Contents

> Project kanban https://github.com/orgs/Integration-Automation/projects/2/views/1

---

- [About](#about)
- [Features](#features)
- [Download](#Download)
- [Dev](#Dev)

---

## About

<details open>

---
> * Notice! BingGPT need cookies file now!
> * Save cookie to bing_cookies.json and put json in program current-working-dir
> - Open bing.com/chat
> - If you see a chat feature, you are good to continue...
> - Install the cookie editor extension for Chrome or Firefox
> - Go to bing.com
> - Open the extension
> - Click "Export" on the bottom right, then "Export as JSON" (This saves your cookies to clipboard)
> - Paste your cookies into a file bing_cookies.json.
> - NOTE: The cookies file name MUST follow the regex pattern bing_cookies.json, so that they could be recognized by
    internal cookie processing mechanisms

* Smart automation assistant.
* Chat based automation.
* User-defined front ground.
* User-defined virtual assistant.
* Assistant can open website.
* Assistant can draw text on your screen.
* Assistant can play video on your screen.
* Assistant can play sound.
* Cowork with another automation components.
* Extendable.
* Remote automation support.

![FrontEngine UI](image/FrontEngine.png)

* Language Menu (Choose ui language)
* UI Style (Choose ui style)
* Tab Menu
    * VIDEO (Setting and show video on front)
    * IMAGE (Setting and show image on front)
    * WEB (Setting and show web on front)
    * GIF AND WEBP (Setting and show gif or webp on front)
    * SOUND (Setting and play sound)
    * TEXT (Setting and show text on front)
    * SCENE (Add multi component on scene and show multi widget, can save setting as file)
    * CHAT (Chat with bing on front)
    * CONTROL CENTER (Control all another widget)

</details>

## Features

<details open>

---

* GIFs need time to load please, wait.

* Video

![Video](gifs/video.gif)

* Website

![Website](gifs/website.gif)

* GIF & WEBP.

![GIF](gifs/play_gif.gif)
![WEBP](gifs/webp.gif)

- [Youtube](https://youtu.be/fewogcb3b8Y)

</details>

## Download

<details open>

---
> Require Windows 10 or 11. \
> If you want to use this on a Unix-like system, you need to compile the source code.

- [Download](https://github.com/Intergration-Automation-Testing/FrontEngine/releases)

> PYPI package: pip install frontengine

</details>

## Dev

<details open>

> Require Python 3.9 or later version

</details>
